<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Systeemmonitor</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Systeemmonitor is een hulpprogramma voor het monitoren van systeembelasting en het bekijken en beheren van processen en achtergronddiensten.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Informatie verbergen</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>Algeheel gebruik</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>Individueel gebruik</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Uitgelezen</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Weggeschreven</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 seconden</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 dagen, %2 uur, %3 minuten</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Gebruik</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Huidige snelheid</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Snelheid</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Maker</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Sockets</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Logische processors</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualisatie</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1i-cache</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1d-cache</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2-cache</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3-cache</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Gemiddelde belasting</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Bestandsomschrijvingen</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Processen</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Processen</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Hostnaam</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Soort besturingssysteem</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Uptime</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 seconden</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Geen zoekresultaat</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Informatie</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Informatie</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>actief</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>aan het herladen</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>inactief</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>mislukt</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>aan het inschakelen</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>aan het uitschakelen</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>zombie</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>niet geladen</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>onjuist afgesteld</translation>
    </message>
    <message>
        <source>error</source>
        <translation>foutmelding</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>samengevoegd</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>gemaskeerd</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>geladen</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>Niet beschikbaar</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Handmatig</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>ingeschakeld</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>uitgeschakeld</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statisch</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>overgankelijk</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>indirect</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>ingeschakeld bij opstarten</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>gemaskeerd</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>gegenereerd</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>zombie</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>vroegtijdig starten</translation>
    </message>
    <message>
        <source>start</source>
        <translation>starten</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>achteraf starten</translation>
    </message>
    <message>
        <source>running</source>
        <translation>wordt uitgevoerd</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>afgesloten</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>herladen</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>stoppen</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>bijhouden stoppen</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>vernietigen</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>geforceerd afsluiten</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>achteraf stoppen</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>écht vernietigen</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>écht geforceerd afsluiten</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>mislukt</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>automatisch herstarten</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Gebruikt</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Beschikbaar</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Gedeeld</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Gecachet</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Buffers</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Gecachet wisselgeheugen</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actief</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Inactief</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Dirty</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Toegewezen</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Totaal wisselgeheugen</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Vrij wisselgeheugen</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Model</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Leessnelheid</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Schrijfsnelheid</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Capaciteit</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Uitgelezen sectoren</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Uitgelezen/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Uitgelezen sectoren/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Uitgelezen+samengevoegd/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Weggeschreven sectoren</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Voltooide wegschrijvingen</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Samengevoegde wegschrijvingen</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Weggeschreven/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Weggeschreven sectoren/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Samengevoegde wegschrijvingen/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Systeem</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Het beëindigen van dit proces kan gegevensverlies veroorzaken.
Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Proces beëindigen</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Het beëindigen van dit proces kan gegevensverlies veroorzaken.
Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Het beëindigen van dit programma kan gegevensverlies veroorzaken.
Weet je zeker dat je door wilt gaan?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Geforceerd afsluiten</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Beëindigen</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>IP-adres:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Netmask:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Uitgezonden:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Voorvoegsel:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Bereik:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Soort verbinding</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Linkkwaliteit</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Signaalsterkte</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Ruisniveau</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Bandbreedte</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>RX-pakketten</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>RX-bytes</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>RX-fouten</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX-loslatingen</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>RX-overvloeiingen</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>RX-frame</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>TX-pakketten</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>TX-bytes</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>TX-fouten</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>TX-overvloeiingen</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>TX-provider</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX-loslatingen</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Opdrachtregel</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Starttijd</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Klik op het programma dat je wilt beëindigen</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Geheugen</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Ontvangen</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>Processor</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Schijfuitlezing</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Schijfwegschrijving</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Geheugen</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Wisselgeheugen</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Niet ingeschakeld</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Totaal ontvangen</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Totaal verstuurd</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Verstuurd</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Schijven</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Erg hoog</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoog</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normaal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Laag</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Erg laag</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Aangepast</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Ongeldig</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Foutmelding: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Het aanpassen van de procesprioriteit is mislukt</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Programma&apos;s</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mijn processen</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Alle processen</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Bezig met laden…</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Het proces kan niet worden onderbroken</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Het proces kan niet worden hervat</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Het proces kan niet worden vernietigd</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Er kan geen signaal worden verstuurd naar het proces</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Het proces kan niet worden beëindigd</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(er worden %1 programma&apos;s en %2 processen uitgevoerd)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Geen antwoord</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Onderbreken</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Systeemvak</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Opdrachtlocatie tonen</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Proces beëindigen</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Proces hervatten</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Geforceerd beëindigen</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Prioriteit aanpassen</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Proces onderbreken</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Aangepaste prioriteit</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Aanpassen</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>Processor</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Geheugen</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Schijfwegschrijving</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Schijfuitlezing</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Gebruiker</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioriteit</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Gedeeld geheugen</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Virtueel geheugen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Niet ondersteund</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Systeembeveiliging</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Waarschuwingen tonen als het gebruik de drempelwaarden overstijgt</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Meldingen</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>Waarschuwingsdrempelwaarde cpu-gebruik (in %)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Waarschuwingsdrempelwaarde geheugengebruik (in %)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Waarschuwingtussenpoos (in min.)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Kan het soort opstart niet instellen</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Foutmelding: kan het soort opstart niet instellen wegens een gecrasht onderliggend proces.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Naam van dienstproces</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Verversen</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Handmatig</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Soort opstart</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Laden</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actief</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Onderliggend</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Omschrijving</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Soort opstart</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(aanpasbaar)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Tussen de %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Programma geforceerd beëindigen</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Uitklappen</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Compact</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Weergave</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Processen</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Diensten</translation>
    </message>
</context>
</TS>
